@@ -16,8 +16,8 @@ package collector
 import (
 	"context"
 	"database/sql"
+	"log/slog"
 
-	"github.com/go-kit/log"
 	"github.com/lib/pq"
 	"github.com/prometheus/client_golang/prometheus"
 )
@@ -28,7 +28,7 @@ func init() {
 }
 
 type PGProcessIdleCollector struct {
-	log log.Logger
+	log *slog.Logger
 }
 
 const processIdleSubsystem = "process_idle"
@@ -56,6 +56,7 @@ func (PGProcessIdleCollector) Update(ctx context.Context, instance *instance, ch
 				COUNT(*) AS process_idle_seconds_count
 				FROM pg_stat_activity
 				WHERE state ~ '^idle'
+				AND pid <> pg_backend_pid()
 				GROUP BY state, application_name
 			),
 			buckets AS (
@@ -72,6 +73,7 @@ func (PGProcessIdleCollector) Update(ctx context.Context, instance *instance, ch
 				FROM
 				pg_stat_activity,
 				UNNEST(ARRAY[1, 2, 5, 15, 30, 60, 90, 120, 300]) AS le
+				WHERE pid <> pg_backend_pid()
 				GROUP BY state, application_name, le
 				ORDER BY state, application_name, le
 			)
